@@ -1,4 +1,3 @@
-import os
 import torch
 
 from ..modules import TransformerEncoder, MaskEmbeddings
@@ -20,15 +19,3 @@ class BertModel(torch.nn.Module):
     def forward(self, input_ids: torch.Tensor, attention_mask: torch.Tensor) -> torch.Tensor:
         embedding_output = self.embeddings(input_ids=input_ids)
         return self.encoder.forward(embedding_output, attention_mask.to(torch.bool))
-
-    @classmethod
-    def from_pretrained(cls, model_path: str) -> 'BertModel':
-        model = cls(
-            vocab_size=28996, dim=1024, padding_idx=0, max_position_embeddings=512,
-            ffn_size=4096, n_heads=16, n_layers=24
-        )
-        model.load_state_dict(state_dict=torch.load(os.path.join(model_path, 'pytorch_model.bin'), map_location='cpu'))
-        model.eval()
-        for p in model.parameters():
-            p.requires_grad = False
-        return model.half()
